@@ -115,7 +115,7 @@
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
 /* Readline */
-/* #undef HAVE_HIST_ENTRY */
+#define HAVE_HIST_ENTRY 1
 /* #undef USE_LIBEDIT_INTERFACE */
 #define USE_NEW_READLINE_INTERFACE 1
 
@@ -203,7 +203,7 @@
 #define HAVE_PTHREAD_SIGMASK 1
 /* #undef HAVE_PTHREAD_YIELD_NP */
 /* #undef HAVE_PTHREAD_YIELD_ZERO_ARG */
-#define PTHREAD_ONCE_INITIALIZER PTHREAD_ONCE_INIT
+/* #undef PTHREAD_ONCE_INITIALIZER */
 #define HAVE_PUTENV 1
 #define HAVE_READDIR_R 1
 #define HAVE_READLINK 1
@@ -394,8 +394,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "earmv4"
-#define DEFAULT_MACHINE "earmv4"
+#define MACHINE_TYPE "earmv7hf"
+#define DEFAULT_MACHINE "earmv7hf"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -532,16 +532,16 @@
 
 #define MYSQL_VERSION_MAJOR 11
 #define MYSQL_VERSION_MINOR 4
-#define MYSQL_VERSION_PATCH 4
+#define MYSQL_VERSION_PATCH 5
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 11.4.4"
+#define PACKAGE_STRING "MySQL Server 11.4.5"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "11.4.4"
-#define VERSION "11.4.4"
+#define PACKAGE_VERSION "11.4.5"
+#define VERSION "11.4.5"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
@@ -564,4 +564,4 @@
 
 #endif
 
-#define HAVE_VFORK 1
+/* #undef HAVE_VFORK */
